package Entity 
{
	import net.flashpunk.FP;
	import net.flashpunk.graphics.Image;
	import Worlds.BaseWorld;
	import Worlds.GameWorld;

	/**
	 * ...
	 * @author lightsoda
	 */
	public class ENpc extends BaseEntity
	{
		[Embed(source = "../../assets/gfx/npcactive.png")] private static const gfxNpcActive:Class;
		[Embed(source = "../../assets/gfx/npcinactive.png")] private static const gfxNpcInactive:Class;
		
		private var m_movementX:Number;
		private var m_movementY:Number;
		private var m_movementXTimer:Number;
		private var m_movementYTimer:Number;
		
		public var m_greeting:String;
		public var m_positive:Array;
		public var m_negative:Array;
		
		public var m_conversationState:int;
		
		public var m_moving:Boolean;
		
		public var m_index = 0;
		public var m_positiveScore = 10;
		public var m_negativeScore = 10;
		public var m_murderScore = 10;
		
		public function ENpc(x:Number, y:Number, moving:Boolean = true) 
		{
			super(x, y);
			
			m_moving = moving;
			
			m_moveSpeed = C.MOVE_SPEED / 2;
			
			var i:Image = new Image(gfxNpcActive);
			graphic = i;
			
			width = i.width;
			height = i.height;
			
			m_movementX = 0;
			m_movementXTimer = 0;
			m_movementY = 0;
			m_movementYTimer = 0;
			
			setHitboxTo(i);
			
			type = C.TYPE_NPC;
			
			m_conversationState = C.STATE_GREETING;
		}
		
		public function SetInactive():void
		{
			graphic = new Image(gfxNpcInactive);
		}
		
		public function GetPositiveScore():int
		{
			var s:int = m_positiveScore;
			m_positiveScore = 0;
			return s;
		}
		
		public function GetNegativeScore():int
		{
			var s:int = m_negativeScore;
			m_negativeScore = 0;
			return s;
		}
		
		public function GetMurderScore():int
		{
			var s:int = m_murderScore;
			m_murderScore = 0;
			return s;
		}
		
		override public function update():void 
		{
			if (BaseWorld(FP.world).m_paused) return;
			
			if (m_moving)
			{
				if (m_movementXTimer <= 0)
				{
					m_movementX = FP.rand(3);
					m_movementY = FP.rand(3);
					
					m_movementXTimer = FP.rand(10);
					m_movementYTimer = FP.rand(10);
				}
				
				switch(m_movementX)
				{
					default:
					case 0:
						break;
					case 1:
						MoveLeft();
						break;
					case 2:
						MoveRight();
						break;
				}
				
				switch(m_movementY)
				{
					default:
					case 0:
						break;
					case 1:
						MoveUp();
						break;
					case 2:
						MoveDown();
						break;
				}
				
				m_movementXTimer -= 1 * FP.elapsed;
				m_movementYTimer -= 1 * FP.elapsed;
			}
			
			super.update();
		}
		
		public function GetNextDialog(positive:Boolean):String
		{
			if (m_conversationState == C.STATE_GREETING)
			{
				if (positive)
				{
					m_conversationState = C.STATE_POSITIVE;
				}
				else
				{
					m_conversationState = C.STATE_NEGATIVE;
				}
				
				return m_greeting;
			}
			else if (m_conversationState == C.STATE_POSITIVE)
			{
				if (m_positive == null) return null;
				
				if (m_positive.length > 0 && m_index < m_positive.length)
				{
					return m_positive[m_index++];
				}
				else
				{
					var s:int = GetPositiveScore();
					m_conversationState = C.STATE_GREETING;
					m_index = 0;
					GetNextDialog(positive);
					GameWorld(world).m_deathTimer += s;
					GameWorld(world).m_persistent.Positive++;
					world.add(new ETempDialog(0, 0, "You gained " + s + " seconds"));
					SetInactive();
				}
			}
			else if (m_conversationState == C.STATE_NEGATIVE)
			{
				if (m_negative == null) return null;

				if (m_negative.length > 0 && m_index < m_negative.length)
				{
					return m_negative[m_index++];
				}
				else
				{
					var s:int = GetNegativeScore();
					m_conversationState = C.STATE_GREETING;
					m_index = 0;
					GetNextDialog(positive);
					GameWorld(world).m_deathTimer -= s;
					GameWorld(world).m_persistent.Negative++;
					world.add(new ETempDialog(0, 0, "You lost " + s + " seconds"));
					SetInactive();
				}
			}
			else if (m_conversationState == C.STATE_DONE)
			{
				return null;
			}
			else return null;
			
			return null;
		}
	}

}