package Entity 
{
	import net.flashpunk.Entity;
	import net.flashpunk.FP;
	import net.flashpunk.graphics.Graphiclist;
	import net.flashpunk.graphics.Image;
	import net.flashpunk.graphics.Text;
	import net.flashpunk.utils.Input;
	import net.flashpunk.utils.Key;
	import Worlds.BaseWorld;
	import Worlds.GameWorld;
	import Worlds.WDeath;
	/**
	 * ...
	 * @author lightsoda
	 */
	public class EPlayer extends BaseEntity
	{
		[Embed(source = "../../assets/gfx/player.png")] private static const gfxPlayer:Class;

		private var m_dialogEntity:Entity;
		private var m_dialogtext:Text;
		
		private var m_dialogSelectEntity:Entity;
		private var m_dialogSelectTextOptionA:Text;
		private var m_dialogSelectTextOptionB:Text;
		private var m_dialogSelectTextOptionC:Text;

		private var m_dialogSelectIndex:int = 0;
		private var m_dialogSelectIndexMax:int = 1;
		
		private var m_interactState:int;
		
		public function EPlayer(x:Number, y:Number) 
		{
			super(x, y);
			
			var i:Image = new Image(gfxPlayer);
			graphic = i;
			
			width = i.width;
			height = i.height;
			
			setHitboxTo(i);
			
			type = C.TYPE_PLAYER;
			
			m_dialogtext = new Text("");
			
			m_dialogEntity = new Entity();
			var dialogImage:Image = CreatePlaceholderImage(512, 50);
			m_dialogEntity.graphic = new Graphiclist(dialogImage, m_dialogtext);
			m_dialogEntity.visible = false;
			
			m_dialogSelectEntity = new Entity();
			var dialogSelectImage:Image = CreatePlaceholderImage(512, 50);
			
			m_dialogSelectTextOptionA = new Text("Positive");
			m_dialogSelectTextOptionA.color = C.COLOR_TEXT_SELECTED;
			
			m_dialogSelectTextOptionB = new Text("Negative");
			m_dialogSelectTextOptionB.color = C.COLOR_TEXT_UNSELECTED;
			m_dialogSelectTextOptionB.y = 10;
			
			m_dialogSelectTextOptionC = new Text("Murder");
			m_dialogSelectTextOptionC.color = C.COLOR_TEXT_UNSELECTED;
			m_dialogSelectTextOptionC.y = 20;
			m_dialogSelectTextOptionC.visible = false;
			
			m_dialogSelectEntity.graphic = new Graphiclist(
				dialogSelectImage,
				m_dialogSelectTextOptionA,
				m_dialogSelectTextOptionB,
				m_dialogSelectTextOptionC);
			
			m_dialogSelectEntity.visible = false;
			
			m_interactState = C.PLAYER_INTERACT_NONE;
			
			FP.world.add(m_dialogEntity);
			FP.world.add(m_dialogSelectEntity);
		}

		override public function update():void 
		{
			if (BaseWorld(FP.world).m_paused == false)
			{
				m_dialogEntity.visible = false;
				m_dialogSelectEntity.visible = false;

				if (Input.check(Key.LEFT))
				{
					MoveLeft();
				}
				else if (Input.check(Key.RIGHT))
				{
					MoveRight();
				}
				
				if(Input.check(Key.UP))
				{
					MoveUp();
				}
				else if (Input.check(Key.DOWN))
				{
					MoveDown();
				}
				
				if (Input.pressed(Key.SHIFT))
				{
					var m_suicide:Array = new Array();
					world.getType(C.TYPE_SUICIDE, m_suicide);
					for each(var su:ESuicide in m_suicide)
					{
						if (collidePoint(x, y, su.x, su.y))
						{
							GameWorld(world).m_persistent.Suicide = true;
							FP.world = new WDeath(GameWorld(world).m_persistent);
						}
					}
				}

				if (Input.pressed(Key.ENTER))
				{
					if (m_collidingWithNpc)
					{
						BaseWorld(FP.world).m_paused = true;
						m_interactState = C.PLAYER_INTERACT_SELECT;
						m_dialogSelectIndex = 1;
					}
				}
			}
			else
			{
				if (m_interactState == C.PLAYER_INTERACT_SELECT)
				{
					if (m_hasKnife)
					{
						m_dialogSelectIndexMax = 2;
						m_dialogSelectTextOptionC.visible = true;
					}
					
					if (m_dialogSelectIndex < 0) m_dialogSelectIndex = m_dialogSelectIndexMax;
					if (m_dialogSelectIndex > m_dialogSelectIndexMax) m_dialogSelectIndex = 0;
					
					if (m_dialogSelectIndex == 1)
					{
						m_dialogSelectTextOptionA.color = C.COLOR_TEXT_SELECTED;
						m_dialogSelectTextOptionB.color = C.COLOR_TEXT_UNSELECTED;
						m_dialogSelectTextOptionC.color = C.COLOR_TEXT_UNSELECTED;
					}
					else if (m_dialogSelectIndex == 0)
					{
						m_dialogSelectTextOptionA.color = C.COLOR_TEXT_UNSELECTED;
						m_dialogSelectTextOptionB.color = C.COLOR_TEXT_SELECTED;
						m_dialogSelectTextOptionC.color = C.COLOR_TEXT_UNSELECTED;
					}
					else if (m_dialogSelectIndex == 2)
					{
						m_dialogSelectTextOptionA.color = C.COLOR_TEXT_UNSELECTED;
						m_dialogSelectTextOptionB.color = C.COLOR_TEXT_UNSELECTED;
						m_dialogSelectTextOptionC.color = C.COLOR_TEXT_SELECTED;
					}
					
					if (Input.pressed(Key.UP)) m_dialogSelectIndex++;
					if (Input.pressed(Key.DOWN)) m_dialogSelectIndex--;
					if (Input.pressed(Key.ENTER))
					{
						if (m_dialogSelectIndex == 2)
						{
							var score:int = m_interactTarget.GetMurderScore();
							m_interactState = C.PLAYER_INTERACT_NONE;
							world.add(new ECorpse(m_interactTarget.x, m_interactTarget.y));
							m_collidingWithNpc = false;
							BaseWorld(world).m_paused = false;
							GameWorld(world).m_deathTimer -= score;
							GameWorld(world).m_persistent.Murders++;
							world.add(new ETempDialog(0, 0, "Your murdered someone"));
							world.add(new ETempDialog(0, 0, "You lost " + score + " seconds"));
							world.remove(m_interactTarget);
							m_interactTarget = null;
						}
						else
						{
							m_dialogtext.text = m_interactTarget.GetNextDialog(m_dialogSelectIndex);
							m_interactState =  C.PLAYER_INTERACT_TALK;
						}
					}

					m_dialogSelectEntity.visible = true;
				}
				else if (m_interactState == C.PLAYER_INTERACT_TALK)
				{
					trace("player talk");
					m_dialogEntity.visible = true;
					m_dialogSelectEntity.visible = false;

					if (Input.pressed(Key.ENTER))
					{
						var s:String = m_interactTarget.GetNextDialog(m_dialogSelectIndex);
						if (s == null)
						{
							m_interactState = C.PLAYER_INTERACT_NONE;
						}
						else
							m_dialogtext.text = s;
					}
					
					if (m_interactTarget.m_conversationState == C.STATE_DONE)
						m_interactState = C.PLAYER_INTERACT_NONE;
				}
				else if (m_interactState == C.PLAYER_INTERACT_NONE)
				{
					BaseWorld(FP.world).m_paused = false;
					m_dialogEntity.visible = false;
					m_dialogSelectEntity.visible = false;
					m_collidingWithNpc = false;
					m_interactTarget.m_conversationState = C.STATE_GREETING;
					m_interactTarget.m_index = 0;
				}
			}

			m_dialogEntity.x = world.camera.x;
			m_dialogEntity.y = world.camera.y + 400;
			
			m_dialogSelectEntity.x = world.camera.x;
			m_dialogSelectEntity.y = world.camera.y + 400;
			
			super.update();
		}
		
		override public function render():void 
		{
			
			super.render();
		}
	}

}