package Worlds 
{
	import Entity.ENpc;
	import Entity.ESuicide;
	import net.flashpunk.Entity;
	import net.flashpunk.FP;
	import net.flashpunk.graphics.Image;
	import net.flashpunk.graphics.Tilemap;
	import net.flashpunk.masks.Grid;
	import net.flashpunk.World;
	/**
	 * ...
	 * @author lightsoda
	 */
	
	public class BaseWorld extends World
	{
		[Embed(source = "../../assets/levels/01.oel", mimeType = "application/octet-stream")] private static var lvl01:Class;
		[Embed(source = "../../assets/gfx/land.png")] private static var tileset:Class;

		protected var m_mapEntity:Entity;
		protected var m_mapFringe:Entity;
		protected var m_mapImage:Image;
		protected var m_mapGrid:Grid;
		protected var m_mapTile:Tilemap;
		protected var m_mapFringeTiles:Tilemap;
		
		protected var m_mapXML:XML;

		public var m_paused:Boolean;
		
		public var m_iMessages:Number = 0;
		
		public function BaseWorld() 
		{
			m_paused = false;
		}

		protected function CreateLevel():void
		{
			m_mapXML = FP.getXML(lvl01);

			m_mapGrid = new Grid(m_mapXML.@width, m_mapXML.@height, C.TILE_SIZE, C.TILE_SIZE);
			
			m_mapGrid.loadFromString(m_mapXML.collision, "", "\n");
			
			m_mapTile = new Tilemap(tileset, m_mapGrid.width, m_mapGrid.height, C.TILE_SIZE, C.TILE_SIZE);
			m_mapTile.loadFromString(m_mapXML.tiles, ",", "\n");

			m_mapEntity = new Entity(0, 0, m_mapTile, m_mapGrid);
			m_mapEntity.type = C.TYPE_MAP;

			m_mapFringeTiles = new Tilemap(tileset, m_mapGrid.width, m_mapGrid.height, C.TILE_SIZE, C.TILE_SIZE);
			m_mapFringeTiles.loadFromString(m_mapXML.fringe, ",", "\n");
			m_mapFringe = new Entity(0, 0, m_mapFringeTiles);

			m_mapImage = new Image(m_mapGrid.data);
			m_mapImage.color = 0xff0000;
			m_mapImage.scale = C.TILE_SIZE;
			m_mapImage.alpha = 0.5;
			
			m_mapEntity.layer = 30;
			m_mapFringe.layer = 20;
			
			add(m_mapEntity);
			add(m_mapFringe);
			
			var npc:XML;
			for each(npc in m_mapXML.entities.npc)
			{
				var b:Boolean = npc.@moving == "True" ? true : false;
				var e:ENpc = new ENpc(npc.@x, npc.@y, b);
				e.m_greeting = npc.@greeting;
				e.m_positive = String(npc.@positivie).split("\r\n");
				e.m_negative = String(npc.@negative).split("\r\n");
				
				add(e);
			}
			
			var suicide:XML;
			for each(suicide in m_mapXML.entities.suicide)
			{
				add(new ESuicide(suicide.@x, suicide.@y));
			}
			
		}
		
		protected function SetCameraTo(e:Entity):void 
		{
			var cx:Number = camera.x + C.SCREEN_CENTER_X + C.TILE_SIZE
			var cy:Number = camera.y + C.SCREEN_CENTER_Y + C.TILE_SIZE;
			
			camera.x -= (cx - (e.x + C.TILE_SIZE * 1.5)) * FP.elapsed * 20;
			camera.y -= (cy - (e.y + C.TILE_SIZE * 1.5)) * FP.elapsed * 20;
		}
		
	}

}
