package Worlds 
{
	import Entity.ENpc;
	import Entity.EStaticNpc;
	import net.flashpunk.Entity;
	import net.flashpunk.FP;
	import net.flashpunk.graphics.Graphiclist;
	import net.flashpunk.graphics.Image;
	import net.flashpunk.graphics.Text;
	import net.flashpunk.utils.Input;
	import net.flashpunk.utils.Key;
	/**
	 * ...
	 * @author lightsoda
	 */
	public class WDeath extends BaseWorld
	{
		[Embed(source = "../../assets/gfx/end.png")] private static const gfxDeath:Class;
		
		private var m_persistent:P;
		private var gameoverTextEntity:Entity;
		private var gameoverText:Text;
		
		private var m_deathTimer = 3;
		
		private var continueEntity:Entity;
		
		public function WDeath(p:P) 
		{
			m_persistent = p;
			m_persistent.PlayMusic("end");
		}
		
		override public function begin():void 
		{
			var backdropEntity:Entity = new Entity();
			var backdropImage:Image = new Image(gfxDeath);
			
			backdropEntity.graphic = backdropImage;
			backdropEntity.layer = 10;
			
			add(backdropEntity);

			gameoverTextEntity = new Entity();
			add(gameoverTextEntity);
			
			gameoverText = new Text("Game Over");
			gameoverText.size = 20;
			gameoverText.align = "center";
			gameoverText.x = C.SCREEN_CENTER_X - gameoverText.width / 2;
			gameoverText.y = C.SCREEN_CENTER_Y - 40;

			var ending:int = 0;
			
			if (m_persistent.Suicide)
			{
				GameoverSuicide();
				ending = 1;
			}
			else if (m_persistent.Murders == 0 && m_persistent.Positive == 0 && m_persistent.Negative == 0)
			{
				GameoverSolitude();
				ending = 1;
			}
			else if (m_persistent.Murders > 0)
			{
				GameoverMurderer();
				ending = 3;
			}
			else if (m_persistent.Positive > 0 && m_persistent.Negative == 0 && m_persistent.Murders == 0)
			{
				GameoverGoodguy();
				ending = 4;
			}
			else if (m_persistent.Negative > 0 && m_persistent.Positive == 0 && m_persistent.Murders == 0)
			{
				GameoverBadguy();
				ending = 5;
			}
			else
			{
				GameoverNeutral();
				ending = 6;
			}

			continueEntity = new Entity();
			var continueText:Text = new Text("Ending " + ending + "/6, press any key to continue");
			continueText.x = C.SCREEN_CENTER_X - continueText.width / 2;
			continueText.y = C.GAME_HEIGHT - continueText.height * 2;
			continueEntity.graphic = continueText;
			add(continueEntity);
			continueEntity.visible = false;

			super.begin();
		}
		
		private function GameoverSuicide():void 
		{
			var t:Text = new Text("You committed suicide");

			var p:Number = 0;
			
			if (m_persistent.Murders > 0)
			{
				t.text += "\nMost people will remember you as a murderer";
			}
			else if (m_persistent.Positive > 0 && m_persistent.Positive > m_persistent.Negative)
			{
				t.text += "\nYour friends will never understand why";
				p = m_persistent.Positive;
			}
			else if (m_persistent.Negative > 0 && m_persistent.Negative > m_persistent.Positive)
			{
				t.text += "\nYour mother showed up for your funeral";
				p = 1;
			}
			
			gameoverTextEntity.graphic = new Graphiclist(gameoverText, t);
			t.align = "center";
			t.x = C.SCREEN_CENTER_X - t.width / 2;
			t.y = C.SCREEN_CENTER_Y;
			
			var ny = 0;
			var ay = 1;
			var nx = 0;
			for (var i:int = 0; i < p; i++)
			{
				if (i % 20 == 0)
				{
					ny += 10;
					//ay += 0.2;
					nx = 0;
				}
				
				var e:EStaticNpc = new EStaticNpc(0, 0, ay);
				e.x = 50 + (20 * nx++);
				e.y = 400 + ny;
				
				add(e);
			}			
		}
		
		private function GameoverNeutral():void 
		{
			var t:Text = new Text("You were mean to some, and good to some\n" + m_persistent.Positive / 2 + " people showed up for your funeral");
			t.align = "center";
			t.x = C.SCREEN_CENTER_X - t.width / 2;
			t.y = C.SCREEN_CENTER_Y;
			
			gameoverTextEntity.graphic = new Graphiclist(gameoverText, t);
			
			var ny = 0;
			var ay = 1;
			var nx = 0;
			for (var i:int = 0; i < m_persistent.Positive / 2; i++)
			{
				if (i % 20 == 0)
				{
					ny += 10;
					//ay += 0.2;
					nx = 0;
				}
				
				var e:EStaticNpc = new EStaticNpc(0, 0, ay);
				e.x = 50 + (20 * nx++);
				e.y = 400 + ny;
				
				add(e);
			}
		}
		
		private function GameoverBadguy():void 
		{
			var t:Text = new Text("Most people didn't like you very much\nOnly your mother showed up for your funeral");
			t.align = "center";
			t.x = C.SCREEN_CENTER_X - t.width / 2;
			t.y = C.SCREEN_CENTER_Y;
			
			gameoverTextEntity.graphic = new Graphiclist(gameoverText, t);
			
			add(new EStaticNpc(50, 400));
		}
		
		private function GameoverGoodguy():void 
		{
			var t:Text = new Text("You were considered to be a nice guy\n" + m_persistent.Positive + " people showed up for your funeral");
			t.align = "center";
			t.x = C.SCREEN_CENTER_X - t.width / 2;
			t.y = C.SCREEN_CENTER_Y;
			
			gameoverTextEntity.graphic = new Graphiclist(gameoverText, t);
			
			var ny = 0;
			var ay = 1;
			var nx = 0;
			for (var i:int = 0; i < m_persistent.Positive; i++)
			{
				if (i % 20 == 0)
				{
					ny += 10;
					//ay += 0.2;
					nx = 0;
				}
				
				var e:EStaticNpc = new EStaticNpc(0, 0, ay);
				e.x = 50 + (20 * nx++);
				e.y = 400 + ny;
				
				add(e);
			}
		}
		
		private function GameoverMurderer():void 
		{
			var t:Text = new Text("You will be remembered as a murderer\nMost people are happy that you are gone");
			t.align = "center";
			t.x = C.SCREEN_CENTER_X - t.width / 2;
			t.y = C.SCREEN_CENTER_Y;
			
			gameoverTextEntity.graphic = new Graphiclist(gameoverText, t);
		}
		
		private function GameoverSolitude():void 
		{
			var t:Text = new Text("You didn't care much for anyone else\nYou died alone");
			t.align = "center";
			t.x = C.SCREEN_CENTER_X - t.width / 2;
			t.y = C.SCREEN_CENTER_Y;
			
			gameoverTextEntity.graphic = new Graphiclist(gameoverText, t);
		}
	
		override public function update():void 
		{
			if (m_deathTimer > 0)
			{
				m_deathTimer -= 1 * FP.elapsed;
			}
			else 
			{
				continueEntity.visible = true;
				
				if (Input.pressed(Key.ANY))
				{
					m_persistent.Murders = 0;
					m_persistent.Positive = 0;
					m_persistent.Negative = 0;
					m_persistent.Suicide = false;
					FP.world = new GameWorld(this.m_persistent);
				}
			}
			
			super.update();
		}
		
	}

}